Spatial Model Editor Documentation
==================================

.. toctree::
   :maxdepth: 1
   :caption: Getting started

   quickstart/get-started
   quickstart/gui-overview
   quickstart/import-geometry
   quickstart/assign-compartments
   quickstart/mesh
   quickstart/species
   quickstart/reactions
   quickstart/parameters
   quickstart/functions
   quickstart/run-simulation

.. toctree::
   :maxdepth: 1
   :caption: Example models

   examples/example-overview
   examples/singlediff
   examples/AB-to-C
   examples/grayscott
   examples/verysimple
   examples/brusselator
   examples/livercells
   examples/circadian
   examples/liver
   examples/selkov
   examples/fitzhughnagumo
   examples/calciumwave

.. toctree::
   :maxdepth: 1
   :caption: User guides

   userguides/work-with-copasi
   userguides/how-to-create-your-own-geometry

.. toctree::
   :maxdepth: 2
   :caption: Python interface

   sme/sme
   sme/notebooks
   sme/api

.. toctree::
   :maxdepth: 2
   :caption: Reference documentation

   reference/dune
   reference/pixel
   reference/parameter-fitting
   reference/mesh
   reference/cli
   reference/maths
   reference/units
   reference/CHANGELOG.md
   reference/source-code
   reference/license

.. toctree::
   :maxdepth: 2
   :caption: Developer documentation

   developer/core
   developer/tests
